#####################################################################
# Example R script for data analyses
# This script is for evaluating the contribution of each variable
# to the diversity of the dominant soil bacteria
#
# Contact:
# Kazuhiro Takemoto (takemoto@bio.kyutech.ac.jp)
#####################################################################

library(spdep)
library(spatialreg)
library(MuMIn)
library(caret)
options(na.action = "na.fail")

# load data
df <- read.csv("dataset_S1.csv")
# extract ecosystem type-specific data
#df <- df[df$Forest==1,] # Forest data
#df <- df[df$Grassland==1,] # Grassland data
#df <- df[df$Shrubland==1,] # Shrubland data

# Normalization
d_sub <- data.frame(
    df[c("Longitude", "Latitude")],
    scale(df[c("pH", "MDR", "UV", "HF", "TS", "AMT")]),
    scale(log(df[c("Aridity_Index", "PSEA", "NPP")])),
    df[c("Forest", "Shrubland", "Grassland")],
    scale(log(abs(df[c("WV")]))),
    scale(df[c("shannon", "simpson", "evenness")]),
    scale(log(df[c("richness")]))
    )

## OLS regression analysis #######################################
res1 <- lm(shannon~AMT+Aridity_Index+HF+MDR+NPP+pH+PSEA+TS+UV+WV,data=d_sub)

res1_models <- dredge(res1,rank="AICc")
res1_best <- get.models(res1_models, subset = 1)[1]
res1_ave <-model.avg(get.models(res1_models, cumsum(weight) <= .95))

# OLS full model
summary(res1)
# OLS best model
summary(res1_best[[1]])
# OLS averaged model
summary(res1_ave)

# check multicollinearity (VIF values)
car::vif(res1) # the full model
car::vif(res1_best[[1]]) # the best model

## Spatial analysis based on SEVM modeling approach ##############
set.seed(5)
long <- d_sub$Longitude
lat <- d_sub$Latitude
n_num <- length(d_sub[[1]])
longlat <- cbind(long+rnorm(n_num)/1000,lat+rnorm(n_num)/1000)
longlat_knn <- knearneigh(longlat,k=2,longlat=T)
longlat_nb <- knn2nb(longlat_knn)
longlat_listw <- nb2listw(longlat_nb)

# Moran's I test for the OLS full model
lm.morantest.exact(res1,longlat_listw)
# Moran's I test for the OLS best model
lm.morantest.exact(res1_best[[1]],longlat_listw)

# A spatial eigenvector mapping (SEVM) modelling approach removing spatial autocorrelation in the model residuals
lagcol <- SpatialFiltering(shannon~1,~AMT+Aridity_Index+HF+MDR+NPP+pH+PSEA+TS+UV+WV-1,data=d_sub,style="W",nb=longlat_nb,ExactEV=T)

res1_corr <- lm(shannon~AMT+Aridity_Index+HF+MDR+NPP+pH+PSEA+TS+UV+WV+fitted(lagcol), data=d_sub)

res1_corr_models <- dredge(res1_corr,rank="AICc",fixed = "fitted(lagcol)")
res1_corr_best <- get.models(res1_corr_models, subset = 1)[1]
res1_corr_ave <- model.avg(get.models(res1_corr_models, cumsum(weight) <= .95))

# SEVM full model
summary(res1_corr)
# SEVM best model
summary(res1_corr_best[[1]])
# SEVM averaged model
summary(res1_corr_ave)

# check multicollinearity (VIF values)
car::vif(res1_corr) # the full model
car::vif(res1_corr_best[[1]]) # the best model

# Moran's I test for the SEVM full model
lm.morantest.exact(res1_corr,longlat_listw)
# Moran's I test for the SEVM best model
lm.morantest.exact(res1_corr_best[[1]],longlat_listw)
